==> igloo_0_1_2.tar.tgz: igloo_0_1_2/igloo/language/1/barnraiser_01/sch_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sch_view.lang.php');

// SECTION
$lang['hdr_schedule'] = 						"add or edit an event";


//HEADER
$lang['hdr_schedule'] = 						"add or edit an event";
$lang['hdr_group_schedule'] = 					"add or edit a group event for group 'GROUPTITLE'.";


// FORMS
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_label_location'] = 					"Location";
$lang['form_label_start_date'] = 				"From date";
$lang['form_label_end_date'] = 					"To date";
$lang['form_label_start_time'] = 				"From time";
$lang['form_label_end_time'] = 					"To time";
$lang['form_all_day'] = 						"This event lasts all day";
$lang['form_label_category'] = 					"Category";
$lang['form_label_status'] = 					"Status";
$lang['form_label_priority'] = 					"Priority";
$lang['form_label_complete'] = 					"Complete";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_comments'] = 					"Allow comments";
$lang['form_body'] = 							"details";
$lang['form_label_preview'] = 					"preview";
$lang['form_just_me'] = 						"just me";
$lang['form_label_allocation'] = 				"Allocation";
$lang['form_label_occurence'] = 				"Occurence";
$lang['form_label_alarm'] = 					"Alarm";


//BODY TEXT
$lang['sub_check_spelling'] = 					"check spelling";//
$lang['txt_publish_help'] =						"How wide do you want the audience of your event to be? You can publish to just your friends, wider degrees of aquaintances or the Splash magazine page.";
$lang['txt_none'] = 							"none";
$lang['txt_header_1'] = 						"1. Event overview";
$lang['txt_overview_intro'] = 					"You can add an event to this community. An event is typically a social gathering or an activity. Add a small synopsis which is a one line description of the event to be used when displaying it in lists.";
$lang['txt_header_2'] = 						"2. Date and time";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your event. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm. Note alarms are emails and sent out approximately every 15 minutes. If you would like this event to repeat occur forever leave the until date blank.";
$lang['txt_header_3'] = 						"3. Details";
$lang['txt_detail_intro'] = 					"Add any details that you wish people to know. Tips on getting there, fees, arrival time, dress code are all examples of detailed information.";
$lang['txt_header_4'] = 						"4. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the event on all lists. Choose one from the list below if desired.";
$lang['txt_header_5'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this event to be published to.";
$lang['txt_header_6'] = 						"6. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";

$lang['txt_publish_node_help'] =				"Submit to 'Stuff' editor";
$lang['txt_publish_auto_node_help'] = 			"Stuff";

$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"public web site";

?>

==> igloo_0_1_7.tar.tgz: igloo_0_1_7/igloo/language/1/barnraiser_01/sch_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sch_view.lang.php');

// SECTION
$lang['hdr_schedule'] = 						"add or edit an event";


//HEADER
$lang['hdr_schedule'] = 						"add or edit an event";


// FORMS
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_label_location'] = 					"Location";
$lang['form_label_start_date'] = 				"From date";
$lang['form_label_end_date'] = 					"To date";
$lang['form_label_start_time'] = 				"From time";
$lang['form_label_end_time'] = 					"To time";
$lang['form_all_day'] = 						"This event lasts all day";
$lang['form_label_category'] = 					"Category";
$lang['form_label_status'] = 					"Status";
$lang['form_label_priority'] = 					"Priority";
$lang['form_label_complete'] = 					"Complete";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_comments'] = 					"Allow comments";
$lang['form_body'] = 							"details";
$lang['form_label_preview'] = 					"preview";
$lang['form_just_me'] = 						"Just me";
$lang['form_label_allocation'] = 				"Allocation";
$lang['form_label_occurence'] = 				"Occurence";
$lang['form_label_alarm'] = 					"Alarm";
$lang['form_public'] = 							"Public web site";
$lang['form_label_track'] = 					"Send me an email when a comment is received";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Event overview";
$lang['txt_overview_intro'] = 					"You can add an event to this community. An event is typically a social gathering or an activity. Add a small synopsis which is a one line description of the event to be used when displaying it in lists.";
$lang['txt_header_2'] = 						"2. Date and time";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your event. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm. Note alarms are emails and sent out approximately every 15 minutes. If you would like this event to repeat occur forever leave the until date blank.";
$lang['txt_header_3'] = 						"3. Details";
$lang['txt_detail_intro'] = 					"Add any details that you wish people to know. Tips on getting there, fees, arrival time, dress code are all examples of detailed information.";
$lang['txt_header_4'] = 						"4. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the event on all lists. Choose one from the list below if desired.";
$lang['txt_header_5'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this event to be published to.";
$lang['txt_header_6'] = 						"7. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_until'] = 							"until";
$lang['txt_none'] = 							"none";
$lang['txt_publish_help'] =						"How wide do you want the audience of your event to be?";
$lang['txt_publish_node_help'] =				"Submit to 'Group' editor for inclusion in the featured page";
$lang['txt_publish_auto_node_help'] = 			"Include in the 'Group' featured page";
$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"Include in the public web site";
$lang['txt_degree_nw'] = 						"My network only";
$lang['txt_publish_all'] = 						"Everyone in our group";
$lang['txt_header_7'] = 						"6. Feedback";


?>
